@@ -1,14 +1,14 @@
-from .adgroups import AdGroups
-from .bidrecommendations import BidRecommendations
+from .adgroups import AdGroups, AdGroupsV3
+from .bidrecommendations import BidRecommendations, KeywordRecommendations
 from .budget_recommendations import BudgetRecommendations
 from .budget_rules_recommendation import BudgetRulesRecommendation
-from .campaigns import Campaigns
+from .campaigns import Campaigns, CampaignsV3
 from .campaign_negative_keywords import CampaignNegativeKeywords
-from .keywords import Keywords
+from .keywords import Keywords, KeywordsV3
 from .negative_keywords import NegativeKeywords
 from .negative_product_targeting import NegativeProductTargeting
-from .product_ads import ProductAds
-from .product_targeting import ProductTargeting
-from .reports import Reports
+from .product_ads import ProductAds, ProductAdsV3
+from .product_targeting import ProductTargeting, ProductTargetingV3
+from .reports import Reports, Reporting
 from .snapshots import Snapshots
 from .suggested_keywords import SuggestedKeywords
